@@ -6,6 +6,7 @@
 
 import collections, urlparse
 
+from learnsprout import constants
 from learnsprout import errors
 
 class Resource(object):
@@ -96,6 +97,8 @@ class ResourceCollection(Resource):
   instance_class = ResourceInstance
   # has accompanying delta routes for data change logs
   has_deltas = True
+  # number of results to retrieve per API result "page", override in subclass or set to None to use server default.
+  pagesize = constants.default_pagesize
 
   def __init__(self, owning_client, base_uri):
     super(ResourceCollection, self).__init__(owning_client, base_uri)
@@ -133,6 +136,8 @@ class ResourceCollection(Resource):
 
     if since:
       params["since"] = since
+    if self.pagesize:
+      params["pagesize"] = self.pagesize
     return IterableResult(self.owning_client, self.instance_from_json, self.uri, params)
 
   def __repr__(self):
@@ -180,6 +185,7 @@ class IterableResult(object):
     support in the LearnSprout API and will automatically pull new results when a page
     has been exhausted.
   """
+
   def __init__(self, owning_client, instance_to_class_func, uri, params):
     self.client = owning_client
     self.uri = uri
@@ -203,10 +209,11 @@ class IterableResult(object):
     """ Makes the actual web requests and populates the results buffer. """
     if not self.__done:
       parameters = self.params.copy()
+
       if self.__next:
         parameters["offset"] = self.__next
 
-      response = self.client.make_request(self.uri, parameters)
+      response = self.client.make_request(self.uri, params=parameters)
       if "status_code" in response and response["status_code"] >= 400:
         raise errors.error_from_json(response)
 
